# Hottings

A command line tool to manage hot reload tasks

## Usage

```
Usage: hottings [OPTIONS] COMMAND [ARGS]...

  A command line tool to manage hot reload tasks

Options:
  --help  Show this message and exit.

Commands:
  add     Add a new hotting task
  init    Init a hotting project
  remove  Remove a hotting task
  start   Start all tasks

```

## LICENSE

MIT

copyright jeremaihloo